:mod:`oasis`.OASISSampler
================================

.. currentmodule:: oasis

.. autoclass:: OASISSampler

   
   .. automethod:: __init__
   

.. Not needed since there is no "Examples" section in the docstrings
.. .. include:: oasis.OASISSampler.examples

.. raw:: html

    <div class="clearer"></div>